@@ -51,7 +51,6 @@
 #endif
 
 #include <X11/Xlib.h>
-#include <QX11Info>
 
 #include <KPluginFactory>
 
@@ -201,14 +200,14 @@ void FontUseItem::applyFontDiff( const QFont &fnt, int fontDiffFlags )
   QFont _font( font() );
 
   if (fontDiffFlags & KFontChooser::FontDiffSize) {
-    _font.setPointSize( fnt.pointSize() );
+    _font.setPointSizeF( fnt.pointSizeF() );
   }
   if (fontDiffFlags & KFontChooser::FontDiffFamily) {
     if (!isFixedOnly() || QFontInfo(fnt).fixedPitch()) _font.setFamily( fnt.family() );
   }
   if (fontDiffFlags & KFontChooser::FontDiffStyle) {
-    _font.setBold( fnt.bold() );
-    _font.setItalic( fnt.italic() );
+    _font.setWeight( fnt.weight() );
+    _font.setStyle( fnt.style() );
     _font.setUnderline( fnt.underline() );
   }
 
@@ -291,7 +290,7 @@ FontAASettings::FontAASettings(QWidget *parent)
 bool FontAASettings::load()
 {
   double     from, to;
-  KXftConfig xft(KXftConfig::constStyleSettings);
+  KXftConfig xft;
 
   if(xft.getExcludeRange(from, to))
      excludeRange->setChecked(true);
@@ -345,7 +344,7 @@ bool FontAASettings::load()
 
 bool FontAASettings::save( bool useAA )
 {
-  KXftConfig   xft(KXftConfig::constStyleSettings);
+  KXftConfig   xft;
   KConfig      kglobals("kdeglobals", KConfig::NoGlobals);
   KConfigGroup grp(&kglobals, "General");
 
@@ -499,24 +498,24 @@ KFonts::KFonts(QWidget *parent, const QVariantList &args)
   QStringList nameGroupKeyRc;
 
   nameGroupKeyRc
-    << i18n("General")        << "General"    << "font"         << ""
-    << i18n("Fixed width")    << "General"    << "fixed"        << ""
-    << i18n("Small")          << "General"    << "smallestReadableFont" << ""
-    << i18n("Toolbar")        << "General"    << "toolBarFont"  << ""
-    << i18n("Menu")           << "General"    << "menuFont"     << ""
-    << i18n("Window title")   << "WM"         << "activeFont"   << ""
-    << i18n("Taskbar")        << "General"    << "taskbarFont"  << ""
-    << i18n("Desktop")        << "General"    << "desktopFont" << "";
+    << i18nc("font usage", "General")       << "General"    << "font"         << ""
+    << i18nc("font usage", "Fixed width")   << "General"    << "fixed"        << ""
+    << i18nc("font usage", "Small")         << "General"    << "smallestReadableFont" << ""
+    << i18nc("font usage", "Toolbar")       << "General"    << "toolBarFont"  << ""
+    << i18nc("font usage", "Menu")          << "General"    << "menuFont"     << ""
+    << i18nc("font usage", "Window title")  << "WM"         << "activeFont"   << ""
+    << i18nc("font usage", "Taskbar")       << "General"    << "taskbarFont"  << ""
+    << i18nc("font usage", "Desktop")       << "General"    << "desktopFont" << "";
 
   QList<QFont> defaultFontList;
 
   // NOTE: keep in sync with kdelibs/kdeui/kernel/kglobalsettings.cpp
 
-  QFont f0("Sans Serif", 10);
-  QFont f1("Monospace", 10);
-  QFont f2("Sans Serif", 8);
-  QFont f3("Sans Serif", 9, QFont::Bold);
-  QFont f4("Sans Serif", 10);
+  QFont f0("Sans Serif", 9); // general/menu/desktop
+  QFont f1("Monospace", 9);
+  QFont f2("Sans Serif", 8); // toolbar
+  QFont f3("Sans Serif", 8); // window title
+  QFont f4("Sans Serif", 9); // taskbar
   QFont f5("Sans Serif", 8); // smallestReadableFont
 
   defaultFontList << f0 << f1 << f5 << f2 << f0 << f3 << f4 << f0;
