@@ -31,6 +31,9 @@ class KlipperTray : public KSystemTrayIcon
 
 public:
     KlipperTray();
+public slots:
+    void slotSetToolTipFromHistory();
+    void passive_popup(const QString& caption, const QString& text);
 private:
     Klipper* m_klipper;
 };
