@@ -40,6 +40,8 @@ Deleted::Deleted( Workspace* ws )
 
 Deleted::~Deleted()
     {
+    if( delete_refcount != 0 )
+        kError(1212) << "Deleted client has non-zero reference count (" << delete_refcount << ")";
     assert( delete_refcount == 0 );
     workspace()->removeDeleted( this, Allowed );
     deleteEffectWindow();
@@ -66,6 +68,7 @@ void Deleted::copyToDeleted( Toplevel* c )
     Toplevel::copyToDeleted( c );
     desk = c->desktop();
     contentsRect = QRect( c->clientPos(), c->clientSize());
+    transparent_rect = c->transparentRect();
     if( WinInfo* cinfo = dynamic_cast< WinInfo* >( info ))
         cinfo->disable();
     Client* client = dynamic_cast<Client*>(c);
@@ -136,6 +139,11 @@ QRect Deleted::decorationRect() const
     return rect().adjusted(-padding_left, -padding_top, padding_top, padding_bottom);
     }
 
+QRect Deleted::transparentRect() const
+    {
+    return transparent_rect;
+    }
+
 } // namespace
 
 #include "deleted.moc"
