@@ -79,6 +79,8 @@ KWinCompositingConfig::KWinCompositingConfig(QWidget *parent, const QVariantList
     KGlobal::locale()->insertCatalog( "kwin_effects" );
     ui.setupUi(this);
     layout()->setMargin(0);
+    ui.verticalSpacer->changeSize(20, KDialog::groupSpacingHint());
+    ui.verticalSpacer_2->changeSize(20, KDialog::groupSpacingHint());
     ui.tabWidget->setCurrentIndex(0);
     ui.statusTitleWidget->hide();
 
@@ -132,14 +134,20 @@ KWinCompositingConfig::KWinCompositingConfig(QWidget *parent, const QVariantList
     mTmpConfigFile.open();
     mTmpConfig = KSharedConfig::openConfig(mTmpConfigFile.fileName());
 
-    if( CompositingPrefs::compositingPossible() )
+    // NOTICE: this is intended to workaround broken GL implementations that successfully segfault on glXQuery :-(
+    KConfigGroup gl_workaround_config(mKWinConfig, "Compositing");
+    const bool checkIsSafe = gl_workaround_config.readEntry("CheckIsSafe", true);
+    if( checkIsSafe && CompositingPrefs::compositingPossible() )
         {
+        gl_workaround_config.writeEntry("CheckIsSafe", false);
+        gl_workaround_config.sync();
         // Driver-specific config detection
         mDefaultPrefs.detect();
         initEffectSelector();
-
         // Initialize the user interface with the config loaded from kwinrc.
         load();
+        gl_workaround_config.writeEntry("CheckIsSafe", true);
+        gl_workaround_config.sync();
         }
     else
         {
@@ -309,7 +317,7 @@ void KWinCompositingConfig::currentTabChanged(int tab)
 void KWinCompositingConfig::loadGeneralTab()
     {
     KConfigGroup config(mKWinConfig, "Compositing");
-    bool enabled = config.readEntry("Enabled", mDefaultPrefs.enableCompositing());
+    bool enabled = config.readEntry("Enabled", mDefaultPrefs.recommendCompositing());
     ui.useCompositing->setChecked( enabled );
     ui.animationSpeedCombo->setCurrentIndex(config.readEntry("AnimationSpeed", 3 ));
 
@@ -333,11 +341,14 @@ void KWinCompositingConfig::loadGeneralTab()
     // window switching
     // Set current option to "none" if no plugin is activated.
     ui.windowSwitchingCombo->setCurrentIndex( 0 );
-    if( effectEnabled( "boxswitch", effectconfig ))
+    KConfigGroup boxswitchconfig(mKWinConfig, "Effect-BoxSwitch");
+    if( effectEnabled( "boxswitch", effectconfig ) && boxswitchconfig.readEntry("TabBox", true))
         ui.windowSwitchingCombo->setCurrentIndex( 1 );
-    if( effectEnabled( "coverswitch", effectconfig ))
+    KConfigGroup coverswitchconfig(mKWinConfig, "Effect-CoverSwitch");
+    if( effectEnabled( "coverswitch", effectconfig ) && coverswitchconfig.readEntry("TabBox", false))
         ui.windowSwitchingCombo->setCurrentIndex( 3 );
-    if( effectEnabled( "flipswitch", effectconfig ))
+    KConfigGroup flipswitchconfig(mKWinConfig, "Effect-FlipSwitch");
+    if( effectEnabled( "flipswitch", effectconfig ) && flipswitchconfig.readEntry("TabBox", false))
         ui.windowSwitchingCombo->setCurrentIndex( 4 );
     KConfigGroup presentwindowsconfig(mKWinConfig, "Effect-PresentWindows");
     if( effectEnabled( "presentwindows", effectconfig ) && presentwindowsconfig.readEntry("TabBox", false) )
@@ -361,6 +372,8 @@ void KWinCompositingConfig::loadGeneralTab()
 
 void KWinCompositingConfig::setupCompositingState( bool active, bool enabled )
     {
+    if( !qgetenv( "KDE_FAILSAFE" ).isNull() )
+        enabled = false;
     // compositing state
     QString stateIcon;
     QString stateText;
@@ -388,7 +401,8 @@ void KWinCompositingConfig::setupCompositingState( bool active, bool enabled )
         stateText = i18n( "Compositing is disabled" );
         stateButtonText = i18n( "Resume Compositing" );
         }
-    ui.compositingStateIcon->setPixmap( KIcon( stateIcon ).pixmap( 32, 32 ) );
+    const int iconSize = (QApplication::fontMetrics().height() > 24) ? 32 : 22;
+    ui.compositingStateIcon->setPixmap( KIcon( stateIcon ).pixmap( iconSize, iconSize ) );
     ui.compositingStateLabel->setText( stateText );
     ui.compositingStateButton->setText( stateButtonText );
     ui.compositingStateIcon->setEnabled( enabled );
@@ -399,7 +413,7 @@ void KWinCompositingConfig::setupCompositingState( bool active, bool enabled )
 bool KWinCompositingConfig::effectEnabled( const QString& effect, const KConfigGroup& cfg ) const
     {
     KService::List services = KServiceTypeTrader::self()->query(
-        "KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_" + effect + "'");
+        "KWin/Effect", "[X-KDE-PluginInfo-Name] == 'kwin4_effect_" + effect + '\'');
     if( services.isEmpty())
         return false;
     QVariant v = services.first()->property("X-KDE-PluginInfo-EnabledByDefault");
@@ -459,7 +473,7 @@ void KWinCompositingConfig::saveGeneralTab()
     KConfigGroup config(mKWinConfig, "Compositing");
     // Check if any critical settings that need confirmation have changed
     if(ui.useCompositing->isChecked() &&
-       ui.useCompositing->isChecked() != config.readEntry("Enabled", mDefaultPrefs.enableCompositing()))
+       ui.useCompositing->isChecked() != config.readEntry("Enabled", mDefaultPrefs.recommendCompositing()))
         m_showConfirmDialog = true;
 
     config.writeEntry("Enabled", ui.useCompositing->isChecked());
@@ -485,44 +499,48 @@ void KWinCompositingConfig::saveGeneralTab()
 #undef WRITE_EFFECT_CONFIG
 
     int windowSwitcher = ui.windowSwitchingCombo->currentIndex();
+    bool boxSwitch              = false;
     bool presentWindowSwitching = false;
+    bool coverSwitch            = false;
+    bool flipSwitch             = false;
     switch( windowSwitcher )
         {
-        case 0:
-            // no effect
-            effectconfig.writeEntry("kwin4_effect_boxswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_coverswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_flipswitchEnabled", false);
-            break;
         case 1:
-            // box switch
-            effectconfig.writeEntry("kwin4_effect_boxswitchEnabled", true);
-            effectconfig.writeEntry("kwin4_effect_coverswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_flipswitchEnabled", false);
+            boxSwitch = true;
             break;
         case 2:
-            // present windows
             presentWindowSwitching = true;
-            effectconfig.writeEntry("kwin4_effect_presentwindowsEnabled", true);
-            effectconfig.writeEntry("kwin4_effect_boxswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_coverswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_flipswitchEnabled", false);
             break;
         case 3:
-            // coverswitch
-            effectconfig.writeEntry("kwin4_effect_boxswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_coverswitchEnabled", true);
-            effectconfig.writeEntry("kwin4_effect_flipswitchEnabled", false);
+            coverSwitch = true;
             break;
         case 4:
-            // flipswitch
-            effectconfig.writeEntry("kwin4_effect_boxswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_coverswitchEnabled", false);
-            effectconfig.writeEntry("kwin4_effect_flipswitchEnabled", true);
+            flipSwitch = true;
             break;
+        default:
+            break; // nothing
         }
-    KConfigGroup presentwindowsconfig(mKWinConfig, "Effect-PresentWindows");
-    presentwindowsconfig.writeEntry("TabBox", presentWindowSwitching);
+    // activate effects if not active
+    if( boxSwitch )
+        effectconfig.writeEntry("kwin4_effect_boxswitchEnabled", true);
+    if( presentWindowSwitching )
+        effectconfig.writeEntry("kwin4_effect_presentwindowsEnabled", true);
+    if( coverSwitch )
+        effectconfig.writeEntry("kwin4_effect_coverswitchEnabled", true);
+    if( flipSwitch )
+        effectconfig.writeEntry("kwin4_effect_flipswitchEnabled", true);
+    KConfigGroup boxswitchconfig( mKWinConfig, "Effect-BoxSwitch" );
+    boxswitchconfig.writeEntry( "TabBox", boxSwitch );
+    boxswitchconfig.sync();
+    KConfigGroup presentwindowsconfig( mKWinConfig, "Effect-PresentWindows" );
+    presentwindowsconfig.writeEntry( "TabBox", presentWindowSwitching );
+    presentwindowsconfig.sync();
+    KConfigGroup coverswitchconfig( mKWinConfig, "Effect-CoverSwitch" );
+    coverswitchconfig.writeEntry( "TabBox", coverSwitch );
+    coverswitchconfig.sync();
+    KConfigGroup flipswitchconfig( mKWinConfig, "Effect-FlipSwitch" );
+    flipswitchconfig.writeEntry( "TabBox", flipSwitch );
+    flipswitchconfig.sync();
 
     int desktopSwitcher = ui.desktopSwitchingCombo->currentIndex();
     switch( desktopSwitcher )
@@ -631,6 +649,17 @@ void KWinCompositingConfig::save()
 
     configChanged(advancedChanged);
 
+    // This assumes that this KCM is running with the same environment variables as KWin
+    // TODO: Detect KWIN_COMPOSE=N as well
+    if( !qgetenv( "KDE_FAILSAFE" ).isNull() && ui.useCompositing->isChecked() )
+        {
+        KMessageBox::sorry( this, i18n(
+            "Your settings have been saved but as KDE is currently running in failsafe "
+            "mode desktop effects cannot be enabled at this time.\n\n"
+            "Please exit failsafe mode to enable desktop effects." ));
+        m_showConfirmDialog = false; // Dangerous but there is no way to test if failsafe mode
+        }
+
     if(m_showConfirmDialog)
         {
         m_showConfirmDialog = false;
@@ -645,15 +674,15 @@ void KWinCompositingConfig::checkLoadedEffects()
     QDBusMessage message = QDBusMessage::createMethodCall( "org.kde.kwin", "/KWin", "org.kde.KWin", "loadedEffects" );
     QDBusMessage reply = QDBusConnection::sessionBus().call( message );
     KConfigGroup effectConfig = KConfigGroup( mKWinConfig, "Compositing" );
-    bool enabledAfter = effectConfig.readEntry( "Enabled", mDefaultPrefs.enableCompositing() );
+    bool enabledAfter = effectConfig.readEntry( "Enabled", mDefaultPrefs.recommendCompositing() );
 
-    if( reply.type() == QDBusMessage::ReplyMessage && enabledAfter )
+    if( reply.type() == QDBusMessage::ReplyMessage && enabledAfter && !getenv( "KDE_FAILSAFE" ))
         {
         effectConfig = KConfigGroup( mKWinConfig, "Plugins" );
         QStringList loadedEffects = reply.arguments()[0].toStringList();
         QStringList effects = effectConfig.keyList();
         QStringList disabledEffects = QStringList();
-        foreach( QString effect, effects )
+        foreach( QString effect, effects ) // krazy:exclude=foreach
             {
             QString temp = effect.mid( 13, effect.length() - 13 - 7 );
             effect.truncate( effect.length() - 7 );
@@ -670,7 +699,7 @@ void KWinCompositingConfig::checkLoadedEffects()
             message.append( "<ul>" );
             foreach( const QString &effect, disabledEffects )
                 {
-                services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == '" + effect + "'");
+                services = trader->query("KWin/Effect", "[X-KDE-PluginInfo-Name] == '" + effect + '\'');
                 message.append( "<li>" );
                 if( !services.isEmpty() )
                     message.append( services.first()->name() );
@@ -705,7 +734,7 @@ void KWinCompositingConfig::defaults()
     {
     ui.tabWidget->setCurrentIndex(0);
 
-    ui.useCompositing->setChecked(mDefaultPrefs.enableCompositing());
+    ui.useCompositing->setChecked(mDefaultPrefs.recommendCompositing());
     ui.effectWinManagement->setChecked(true);
     ui.effectShadows->setChecked(true);
     ui.effectAnimations->setChecked(true);
