@@ -68,6 +68,9 @@ Rules::Rules()
     , acceptfocusrule( UnusedForceRule )
     , moveresizemoderule( UnusedForceRule )
     , closeablerule( UnusedForceRule )
+    , autogrouprule( UnusedForceRule )
+    , autogroupfgrule( UnusedForceRule )
+    , autogroupidrule( UnusedForceRule )
     , strictgeometryrule( UnusedForceRule )
     , shortcutrule( UnusedSetRule )
     , disableglobalshortcutsrule( UnusedForceRule )
@@ -168,6 +171,9 @@ void Rules::readFromCfg( const KConfigGroup& cfg )
     READ_FORCE_RULE( acceptfocus, , false);
     READ_FORCE_RULE( moveresizemode,Options::stringToMoveResizeMode, QString());
     READ_FORCE_RULE( closeable, , false);
+    READ_FORCE_RULE( autogroup,, false);
+    READ_FORCE_RULE( autogroupfg,, true);
+    READ_FORCE_RULE( autogroupid,, QString());
     READ_FORCE_RULE( strictgeometry, , false);
     READ_SET_RULE( shortcut, ,QString() );
     READ_FORCE_RULE( disableglobalshortcuts, , false);
@@ -252,6 +258,9 @@ void Rules::write( KConfigGroup& cfg ) const
     WRITE_FORCE_RULE( acceptfocus, );
     WRITE_FORCE_RULE( moveresizemode, Options::moveResizeModeToString );
     WRITE_FORCE_RULE( closeable, );
+    WRITE_FORCE_RULE( autogroup, );
+    WRITE_FORCE_RULE( autogroupfg, );
+    WRITE_FORCE_RULE( autogroupid, );
     WRITE_FORCE_RULE( strictgeometry, );
     WRITE_SET_RULE( shortcut, );
     WRITE_FORCE_RULE( disableglobalshortcuts, );
@@ -288,6 +297,9 @@ bool Rules::isEmpty() const
         && acceptfocusrule == UnusedForceRule
         && moveresizemoderule == UnusedForceRule
         && closeablerule == UnusedForceRule
+        && autogrouprule == UnusedForceRule
+        && autogroupfgrule == UnusedForceRule
+        && autogroupidrule == UnusedForceRule
         && strictgeometryrule == UnusedForceRule
         && shortcutrule == UnusedSetRule
         && disableglobalshortcutsrule == UnusedForceRule );
@@ -612,6 +624,9 @@ APPLY_FORCE_RULE( fsplevel, FSP, int )
 APPLY_FORCE_RULE( acceptfocus, AcceptFocus, bool )
 APPLY_FORCE_RULE( moveresizemode, MoveResizeMode, Options::MoveResizeMode )
 APPLY_FORCE_RULE( closeable, Closeable, bool )
+APPLY_FORCE_RULE( autogroup, Autogrouping, bool )
+APPLY_FORCE_RULE( autogroupfg, AutogroupInForeground, bool )
+APPLY_FORCE_RULE( autogroupid, AutogroupById, QString )
 APPLY_FORCE_RULE( strictgeometry, StrictGeometry, bool )
 APPLY_RULE( shortcut, Shortcut, QString )
 APPLY_FORCE_RULE( disableglobalshortcuts, DisableGlobalShortcuts, bool )
@@ -674,6 +689,9 @@ void Rules::discardUsed( bool withdrawn )
     DISCARD_USED_FORCE_RULE( acceptfocus );
     DISCARD_USED_FORCE_RULE( moveresizemode );
     DISCARD_USED_FORCE_RULE( closeable );
+    DISCARD_USED_FORCE_RULE( autogroup );
+    DISCARD_USED_FORCE_RULE( autogroupfg );
+    DISCARD_USED_FORCE_RULE( autogroupid );
     DISCARD_USED_FORCE_RULE( strictgeometry );
     DISCARD_USED_SET_RULE( shortcut );
     DISCARD_USED_FORCE_RULE( disableglobalshortcuts );
@@ -794,6 +812,9 @@ CHECK_FORCE_RULE( FSP, int )
 CHECK_FORCE_RULE( AcceptFocus, bool )
 CHECK_FORCE_RULE( MoveResizeMode, Options::MoveResizeMode )
 CHECK_FORCE_RULE( Closeable, bool )
+CHECK_FORCE_RULE( Autogrouping, bool )
+CHECK_FORCE_RULE( AutogroupInForeground, bool )
+CHECK_FORCE_RULE( AutogroupById, QString )
 CHECK_FORCE_RULE( StrictGeometry, bool )
 CHECK_RULE( Shortcut, QString )
 CHECK_FORCE_RULE( DisableGlobalShortcuts, bool )
@@ -849,6 +870,9 @@ void Client::applyWindowRules()
     QSize s = adjustedSize();
     if( s != size())
         resizeWithChecks( s );
+    // Autogrouping : Only checked on window manage
+    // AutogroupInForeground : Only checked on window manage
+    // AutogroupById : Only checked on window manage
     // StrictGeometry
     setShortcut( rules()->checkShortcut( shortcut().toString()));
     // see also Client::setActive()
